# defipy
Python package for DeFi modelling
* Currently in Beta (version 0.0.2) until fully tested and analyzed

## Install
To install package:
```
> git clone https://github.com/icmoore/defipy
> pip install .
```
or
```
> pip install DeFiPy
```

## DeFi Overview
	* Python for DeFi analytics
